@@ -21,13 +21,14 @@
 #include <KDE/KCmdLineArgs>
 #include <QDebug>
 #include <QDir>
+#include <QCoreApplication>
 
 MultiplePlaylistModel::MultiplePlaylistModel(QObject* parent): QAbstractListModel(parent)
 {
-    QString dirPath = KGlobal::dirs()->saveLocation("data") + KCmdLineArgs::appName() + "/playlists/";
+    QString dirPath = MediaCenter::dataDirForComponent("playlists");
     QDir dir(dirPath);
     QStringList playlistList = dir.entryList (QDir::NoDotAndDotDot | QDir::Files);
-    foreach (QString str, playlistList) {
+    foreach (const QString &str, playlistList) {
         m_multiplePlaylistList.append(str);
     }
     if (playlistList.length() == 0) {
@@ -42,7 +43,7 @@ MultiplePlaylistModel::~MultiplePlaylistModel()
 
 int MultiplePlaylistModel::rowCount(const QModelIndex& parent) const
 {
-
+    Q_UNUSED(parent);
     return m_multiplePlaylistList.size();
 }
 
@@ -61,10 +62,12 @@ QVariant MultiplePlaylistModel::data(const QModelIndex& index, int role) const
 void MultiplePlaylistModel::createNewPlaylist(const QString& name)
 {
     const int n = rowCount();
+
     beginInsertRows(QModelIndex(), n, n);
     m_multiplePlaylistList.append(name);
     endInsertRows();
-    m_playlistModel->setNewPlaylist(name);
+
+    m_playlistModel->setPlaylistName(name);
 }
 
 void MultiplePlaylistModel::setPlaylistModelAddress(QObject* model)
@@ -75,7 +78,7 @@ void MultiplePlaylistModel::setPlaylistModelAddress(QObject* model)
     }
 }
 
-QObject* MultiplePlaylistModel::playlistModelAddress()
+QObject* MultiplePlaylistModel::playlistModelAddress() const
 {
     return m_playlistModel;
 }
@@ -83,7 +86,8 @@ QObject* MultiplePlaylistModel::playlistModelAddress()
 void MultiplePlaylistModel::switchToPlaylist(const QString &name)
 {
     if (!name.isEmpty()) {
-        m_playlistModel->switchToPlaylist(name);
+        m_playlistModel->setPlaylistName(name);
+        emit currentIndexChanged();
     }
 }
 
@@ -97,8 +101,8 @@ void MultiplePlaylistModel::removeCurrentPlaylist()
      */
 
     beginResetModel();
-    QString currPlaylist = m_playlistModel->playlistName();
-    int previousIndex = m_multiplePlaylistList.indexOf(currPlaylist) - 1;
+    const QString currentPlaylist = m_playlistModel->playlistName();
+    int previousIndex = m_multiplePlaylistList.indexOf(currentPlaylist) - 1;
     if (m_multiplePlaylistList.length() == 1 ) {
         m_playlistModel->removeCurrentPlaylist(m_multiplePlaylistList.at(0));
     } else {
@@ -109,9 +113,14 @@ void MultiplePlaylistModel::removeCurrentPlaylist()
             status = m_playlistModel->removeCurrentPlaylist(m_multiplePlaylistList.at(1));
         }
         if (status) {
-            m_multiplePlaylistList.removeOne (currPlaylist);
+            m_multiplePlaylistList.removeOne (currentPlaylist);
         }
     }
     endResetModel();
 }
 
+int MultiplePlaylistModel::currentIndex() const
+{
+    PlaylistModel *p = qobject_cast<PlaylistModel*> (playlistModelAddress());
+    return m_multiplePlaylistList.indexOf(p->playlistName());
+}
