@@ -26,10 +26,12 @@
 #include "mediacenter_export.h"
 #include "mediacenter.h"
 
+class KCmdLineArgs;
 class MEDIACENTER_EXPORT PlaylistModel : public QAbstractListModel
 {
     Q_OBJECT
-    Q_PROPERTY(int currentIndex READ currentIndex WRITE setCurrentIndex NOTIFY currentIndexChanged)
+    Q_PROPERTY(int currentIndex READ currentIndex NOTIFY currentIndexChanged)
+    Q_PROPERTY(QString currentUrl READ currentUrl NOTIFY currentUrlChanged)
 
 public:
     enum Roles {
@@ -44,24 +46,30 @@ public:
     virtual QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const;
     virtual int rowCount(const QModelIndex& parent = QModelIndex()) const;
     Q_INVOKABLE  void addToPlaylist(const QString &url);
-    Q_INVOKABLE QString getNextUrl();
-    Q_INVOKABLE QString getPreviousUrl();
+    Q_INVOKABLE  void playNext();
+    Q_INVOKABLE  void playPrevious();
     Q_INVOKABLE void clearPlaylist();
     Q_INVOKABLE void removeFromPlaylist(const int &index);
     Q_INVOKABLE QString getUrlofFirstIndex();
-    Q_INVOKABLE void moveItem(int firstIndex,int secondIndex);
+    Q_INVOKABLE void moveItem(int originalIndex, int newIndex);
     int currentIndex() const;
     void setCurrentIndex(int index);
     bool random() const;
     Q_INVOKABLE void shuffle();
-    void setNewPlaylist (QString name);
-    void switchToPlaylist (QString name);
-    bool removeCurrentPlaylist (QString playlistName);
-    QString playlistName();
+    bool removeCurrentPlaylist (const QString& playlistToSwitchToAfterDeletion);
+    bool processCommandLineArgs(const KCmdLineArgs *args);
+    void play(int index);
+
+    QString playlistName() const;
+    void setPlaylistName(const QString &name);
+    QString getPlaylistPath() const;
+
+    QString currentUrl() const;
 
 Q_SIGNALS:
     void currentIndexChanged();
     void randomChanged();
+    void currentUrlChanged();
 
 public Q_SLOTS:
     void savePlaylist();
@@ -74,9 +82,10 @@ private:
     Private * const d;
 
     void loadFromFile(const QString &path);
-    void saveToFile(const QString &path);
+    void saveToFile(const QString &path) const;
     QString playlistFilePath() const;
-    QString m_playlistName;
+    void clearPlaylistWithoutModelReset();
+    int addToPlaylist(const QStringList &urls);
 };
 
 #endif // PLAYLISTMODEL_H
